<?php
/**
 * wordify functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package wordifyVibrant
 * @subpackage wordify Blog
 * @since 1.0.0
 */
if ( ! function_exists( 'wordify_blog_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 * 
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function wordify_blog_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on wordify, use a find and replace
		 * to change 'wordify-blog' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'wordify', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );


		add_theme_support( 'custom-header' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// Set default post thumbnail. 16:9.
		set_post_thumbnail_size( 768, 432, true );

		add_image_size( 'gridpost', 350, 234, false );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'wordify_primary_menu'     => esc_html__( 'Primary Menu', 'wordify' ),
			'wordify_footer_menu'      => esc_html__( 'Footer Menu', 'wordify' ),
			'wordify_quick_link_menu'  => esc_html__( 'Quick Link Menu', 'wordify' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'wordify_blog_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// add post-formats to default post type 'posts'

        if ( false != get_post_format() ) {
		    add_theme_support( 'post-formats', array( 'aside', 'gallery', 'video', 'audio', 'quote' ) );
		}

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 50,
			'width'       => 400,
			'flex-width'  => true,
			'flex-height' => true,
		) );
 
        /**
		 * Add support for core custom Content Width.
		 *
		 * @link https://codex.wordpress.org/Content_Width
		 */
		$defaults = array(
			'post'       => '500',
			'page'       => '500',
			'attachment' => '650',
			'artist'     => '300',
			'movie'      => '400'
		);
		add_theme_support( 'content-width', $defaults );

		if ( ! isset( $content_width ) ) {
			$content_width = 600;
		}
	}
endif;
add_action( 'after_setup_theme', 'wordify_blog_setup' );


function wordify_add_editor_styles() {

    add_editor_style( 'assets/css/custom-editor-style.css' );
}
add_action( 'admin_init', 'wordify_add_editor_styles' );


/**
 * Set the theme version, based on theme stylesheet.
 *
 * @global string $wordify_blog_theme_version
 */
function wordify_blog_theme_info() {
	$wordify_blog_theme_info = wp_get_theme();
	$GLOBALS['wordify_blog_theme_version'] = $wordify_blog_theme_info->get( 'Version' );
}
add_action( 'after_setup_theme', 'wordify_blog_theme_info', 0 );

// FAQ about Configuration Validator
add_filter( 'wpcf7_validate_configuration', '__return_false' );


function add_menuclass($ulclass) {
   return preg_replace('/<a /', '<a class="nav-link"', $ulclass);
}
add_filter('wp_nav_menu','add_menuclass');

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';
/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';
/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/navwalker.php';
/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/cv-customizer.php';
/**
 * Custom function for widgets
 */
require get_template_directory() . '/inc/widgets/cv-widget-functions.php';
/**
 * Custom function for metabox
 */
require get_template_directory() . '/inc/metabox.php';
/**
 * Custom Comment Form
 */
require get_template_directory() . '/inc/commentform.php';
/**
 * Load TGM
 */
require get_template_directory() . '/inc/tgm/cv-recommended-plugins.php';


