<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package wordifyVibrant
 * @subpackage wordify Functions
 * @since 1.0.0

 * Register Google fonts for wordify
 *
 * @return string Google fonts URL for the theme.
 */
if ( ! function_exists( 'wordify_blog_fonts_url' ) ) :
    function wordify_blog_fonts_url() {
        $fonts_url = '';
        $font_families = array();
        /*
         * Translators: If there are characters in your language that are not supported
         * by Roboto Condensed, translate this to 'off'. Do not translate into your own language.
         */
        if ( 'off' !== _x( 'on', 'Josefin Sans Display font: on or off', 'wordify' ) ) {
            $font_families[] = 'Josefin+Sans:300, 400,700';
        }

        if ( 'off' !== _x( 'on', 'Inconsolata:400,700 font: on or off', 'wordify' ) ) {
            $font_families[] = 'Inconsolata:400,700';
        }

        if( $font_families ) {
            $query_args = array(
                'family' => urlencode( implode( '|', $font_families ) ),
                'subset' => urlencode( 'latin,latin-ext' ),
            );

            $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
        }

        return $fonts_url;
    }
endif;

/**
 * Enqueue scripts and styles.
 */
function wordify_blog_scripts() {

    global $wordify_blog_theme_version;

    wp_enqueue_style( 'wordify-blog-fonts', wordify_blog_fonts_url(), array(), null );

    wp_enqueue_style( 'bootstrap', get_template_directory_uri(). '/assets/css/bootstrap.css', array(), '3.5.1' );
    wp_enqueue_style( 'animate', get_template_directory_uri(). '/assets/css/animate.css', array(), '3.5.1' );
    wp_enqueue_style( 'owlcarousel', get_template_directory_uri(). '/assets/css/owl.carousel.min.css', array(), '3.5.1' );
    wp_enqueue_style( 'ionicons', get_template_directory_uri(). '/assets/fonts/ionicons/css/ionicons.min.css', array(), '3.5.1' );
    wp_enqueue_style( 'ionicons', get_template_directory_uri(). '/assets/fonts/ionicons/css/ionicons.min.css', array(), '3.5.1' );
    wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/fonts/fontawesome/css/font-awesome.min.css', array(), '3.5.1' );
    wp_enqueue_style( 'flaticon', get_template_directory_uri() . '/assets/fonts/flaticon/font/flaticon.css', array(), '3.5.1' );
    wp_enqueue_style( 'themestyle', get_template_directory_uri() . '/assets/css/style.css', array(), '3.5.1' );
    wp_enqueue_style( 'wordify-blog-style', get_stylesheet_uri(), array(), esc_attr( $wordify_blog_theme_version ) );


    
    wp_enqueue_script( 'wordify-jquery', get_template_directory_uri() . '/assets/js/jquery-3.2.1.min.js', array('jquery'), '1.1.0', true );

    wp_enqueue_script( 'popper', get_template_directory_uri() . '/assets/js/jquery-migrate-3.0.0.js', array('jquery'), '1.1.0', true );

    wp_enqueue_script( 'bootstrap-js', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array('jquery'), '1.1.0', true );

    wp_enqueue_script( 'carousel-js', get_template_directory_uri() . '/assets/js/owl.carousel.min.js', array('jquery'), '1.1.0', true );

    wp_enqueue_script( 'waypoints-js', get_template_directory_uri() . '/assets/js/jquery.waypoints.min.js', array('jquery'), '1.1.0', true );

    wp_enqueue_script( 'stellar-js', get_template_directory_uri() . '/assets/js/jquery.stellar.min.js', array('jquery'), '1.1.0', true );

    wp_enqueue_script( 'main-js', get_template_directory_uri() . '/assets/js/main.js', array('jquery'), '1.1.0', true );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

}
add_action( 'wp_enqueue_scripts', 'wordify_blog_scripts' );

/**
 * Admin Enqueue scripts.
 */
function footer_widget_script(){

    wp_enqueue_media(); 

    wp_enqueue_style( 'admin_style', get_theme_file_uri().'/assets/css/admin_style.css', array(), '3.5.1' );
   
    wp_register_script('admin_custom', get_theme_file_uri().'/assets/js/admin_custom_script.js');

    wp_enqueue_script('admin_custom');

}
add_action('admin_enqueue_scripts','footer_widget_script');

// Footer Content Functions

function custom_footer_function(){
    ?>
    <footer class="site-footer">
        <div class="container">
            <div class="row mb-5">
                <?php 
                if ( is_active_sidebar( 'footer-1' ) ) { ?>
                    <?php dynamic_sidebar( 'footer-1' ); ?>
                <?php } 
                ?>
                <div class="col-md-6 ml-auto">
                    <div class="row">
                        <?php 
                        if ( is_active_sidebar( 'footer-2' ) ) { ?>
                            <?php dynamic_sidebar( 'footer-2' ); ?>
                        <?php } 
                        ?>
                        <div class="col-md-1"></div>
                        <div class="col-md-4">
                            <?php 
                            if ( is_active_sidebar( 'footer-3' ) ) { ?>
                                <?php dynamic_sidebar( 'footer-3' ); ?>
                            <?php } 
                            ?>
                        </div>
                    </div>
                </div>
            </div>
            <div class="row">
                <div class="col-md-12 text-center">
                    <p class="small"><?php echo get_theme_mod('copyright_text'); ?></p>
                </div>
            </div>
        </div>
    </footer>
    <!-- END footer -->
    </div>
    <!-- loader -->
    <?php if(true === get_theme_mod('preloader_visibility')) : ?>
    <div id="loader" class="show fullscreen"><svg class="circular" width="48px" height="48px"><circle class="path-bg" cx="24" cy="24" r="22" fill="none" stroke-width="4" stroke="#eeeeee"/><circle class="path" cx="24" cy="24" r="22" fill="none" stroke-width="4" stroke-miterlimit="10" stroke="#f4b214"/></svg></div>
    <?php endif; ?>
    <?php 
}