<?php
/**
 * CV: Latest Posts
 *
 * Widget show the latest post with thumbnail.
 *
 * @package wordifyVibrant
 * @subpackage wordify Custom Header
 * @since 1.0.0
 */
class wordify_Blog_Latest_Posts extends WP_Widget{
    public function __construct(){
        parent:: __construct('wordify_Blog_Latest_Posts','CV: Latest Posts', array(
            'description' => __('A widget to display the latest posts with thumbnail.', 'wordify')
        ));
    }
    public function widget($args, $instance){
        echo $args['before_widget'].$args['before_title'].$instance['post_title'].$args['after_title']; 
        ?>
        <div class="post-entry-sidebar">
            <ul>
                <?php 
                $postNumber = $instance['post_number'];
                $latestblog = array(
                    'post_type' => 'post',
                    'posts_per_page' => $postNumber
                );
                // the query
                $latestblogquery = new WP_Query( $latestblog ); ?>
                 
                <?php if ( $latestblogquery->have_posts() ) : ?>
                    <!-- the loop -->
                    <?php while ( $latestblogquery->have_posts() ) : $latestblogquery->the_post(); ?>
                    <li>
                        <a href="<?php the_permalink(); ?>">
                            <?php 
                            if(isset($instance['post_image_show'])) : ?>
                                <img src="<?php the_post_thumbnail_url();?>" alt="Image placeholder" class="mr-4">
                            <?php endif; ?>
                            <div class="text">
                                <?php 
                                // latest post title
                                if ( is_single() ) {
                                    the_title( '<h4>', '</h4>' );
                                } elseif ( is_front_page() && is_home() ) {
                                    the_title( '<h4>', '</h4>' );
                                } else {
                                    the_title( '<h4>', '</h4>' );
                                }
                                // latest post date
                                if(isset($instance['post_date_show'])) : ?>
                                <div class="post-meta">
                                    <span class="mr-2"><?php echo get_the_date('M d, Y'); ?></span>
                                </div>
                                <?php endif; ?>
                            </div>
                        </a>
                    </li>
                    <?php endwhile; ?>

                    <?php wp_reset_postdata(); ?>
                <?php else : ?>
                    <p><?php echo esc_html__('Sorry, no posts matched your criteria.','wordify'); ?></p>
                <?php endif; ?>
            </ul>
        </div>
        <?php echo $args['after_widget'];
    }
    public function form($instance){ 
        ?>
        <p>
            <label for="<?php echo $this->get_field_name('post_title'); ?>"><?php echo esc_html__('Title:','wordify');?> </label>
            <input type="text" name="<?php echo $this->get_field_name('post_title'); ?>" id="<?php echo $this->get_field_id('post_title'); ?>" class="widefat" value="<?php echo $instance['post_title'];?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_name('post_number'); ?>"><?php _e('Number of posts to show:', 'wordify');?></label>
            <input class="tiny-text" id="<?php echo $this->get_field_id('post_number'); ?>" name="<?php echo $this->get_field_name('post_number'); ?>" type="number" step="1" min="1" value="<?php echo $instance['post_number'];?>" size="3">
        </p>
        <p>
            <input class="checkbox" type="checkbox" <?php if(isset($instance['post_date_show'])){echo 'checked="checked"'; }?> id="<?php echo $this->get_field_id('post_date_show'); ?>" name="<?php echo $this->get_field_name('post_date_show'); ?>">
            <label for="<?php echo $this->get_field_name('post_date_show'); ?>"><?php _e('Display post date?', 'wordify'); ?></label>
        </p>
        <p>
            <input class="checkbox" type="checkbox" <?php if(isset($instance['post_image_show'])){echo 'checked="checked"'; }?> id="<?php echo $this->get_field_id('post_image_show'); ?>" name="<?php echo $this->get_field_name('post_image_show'); ?>">
            <label for="<?php echo $this->get_field_name('post_image_show'); ?>"><?php _e('Display post Image?', 'wordify');?></label>
        </p>
        <?php 
    }
} 
