<?php

/**
 * custom function and work related to widgets.
 *
 * @package wordifyVibrant
 * @subpackage wordify Custom Header
 * @since 1.0.0
 */

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function wordify_blog_widgets_init() {

	// Sidebar Widgets
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'wordify' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'wordify' ),
		'before_widget' => '<div class="sidebar-box search-form-wrap">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="heading">',
		'after_title'   => '</h3>',
	) );
	// Footer 1 Widgets
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 1', 'wordify' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Add widgets here.', 'wordify' ),
		'before_widget' => '<div class="col-md-4">',
		'after_widget'  => '</div>',  
		'before_title'  => '<h3>',
		'after_title'   => '</h3>',
	) );
	// Footer 2 Widgets
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 2', 'wordify' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'Add widgets here.', 'wordify' ),
		'before_widget' => '<div class="col-md-7">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3>',
		'after_title'   => '</h3>',
	) );
	// Footer 3 Widgets
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 3', 'wordify' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'Add widgets here.', 'wordify' ),
		'before_widget' => '<div class="mb-5">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3>',
		'after_title'   => '</h3>',
	) );
	
}
add_action( 'widgets_init', 'wordify_blog_widgets_init' );

/*-----------------------------------------------------------------------------------------------------------------------*/
/**
 * Register different widgets
 *
 * @since 1.0.1
 */
add_action( 'widgets_init', 'wordify_blog_register_widgets' );

function wordify_blog_register_widgets() {

	// Author Info
	register_widget( 'author_info_widget' );
	// Sidebar Search
	register_widget( 'blog_sidebar_widget' );
	// Latest Posts
	register_widget( 'wordify_Blog_Latest_Posts' );
	// Posts Categories
	register_widget( 'wordify_posts_categories' );
	// Posts Tags
	register_widget( 'wordify_posts_tags' );
	// Footer One
	register_widget( 'about_us_footer_widget' );
	// WP Menu Widgets
	register_widget( 'Updated_WP_Nav_Menu_Widget' );
	// Footer Social Link
	register_widget( 'footer_social_link_widget' );

}

/*-----------------------------------------------------------------------------------------------------------------------*/
/**
 * Load widget required files
 *
 * @since 1.0.0
 */
require get_template_directory() . '/inc/widgets/cv-author-info.php';      // Author Info
require get_template_directory() . '/inc/widgets/cv-sidebar-search.php';   // Sidebar Search
require get_template_directory() . '/inc/widgets/cv-latest-posts.php';     // Latest Posts
require get_template_directory() . '/inc/widgets/cv-posts-categories.php'; // Post Categories
require get_template_directory() . '/inc/widgets/cv-ports-tags.php';       // Post tags
require get_template_directory() . '/inc/widgets/cv-about-us.php';         // Footer One Widgets
require get_template_directory() . '/inc/widgets/cv-quick-menu.php';       // Footer One Widgets
require get_template_directory() . '/inc/widgets/cv-socials-widget.php';   // Footer Socail Widgets