<?php 
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package wordifyVibrant
 * @subpackage wordify Blog
 * @since 1.0.0
 */
get_header();?>
<section class="site-section pt-5 pb-5">
  <div class="container">
    <div class="row">
      <div class="col-md-12">
        <div class="owl-carousel owl-theme home-slider">
        <?php 
          $sliderblog = array(
            'post_type'       => 'post',
            'posts_per_page'  => 3,
            'meta_key' => 'meta-checkbox',
            'meta_value' => 'yes'
          );
          // the query
          $sliderblogquery = new WP_Query( $sliderblog ); ?>
           
          <?php if ( $sliderblogquery->have_posts() ) : ?>
            <!-- the loop -->
            <?php while ( $sliderblogquery->have_posts() ) : $sliderblogquery->the_post(); ?>
              <div>
                <div class="a-block d-flex align-items-center height-lg" style="background-image: url(<?php the_post_thumbnail_url();?>); ">
                  <div class="text half-to-full">
                    <span class="categorypost mb-5">
                    <?php 
                      $category_detail=get_the_category($post->ID);
                      foreach($category_detail as $cd){
                        echo $cd->cat_name;
                      }
                    ?>
                    </span>
                    <div class="post-meta">
                      <span class="author mr-2">
                        <?php if($avatar = get_avatar(get_the_author_meta('ID')) !== FALSE): ?>
                          <?php echo get_avatar( get_the_author_meta( 'ID' ), 32 ); ?> <?php the_author(); ?>
                        <?php else: ?>
                          <img src="<?php echo esc_url(get_template_directory_uri()); ?>/assets/images/person_1.jpg" alt="">  
                        <?php endif; ?>
                      </span>&bullet;
                      <span class="mr-2"><?php echo get_the_date('M d, Y'); ?></span> &bullet;
                      <span class="ml-2"><span class="fa fa-comments"></span> <?php comments_popup_link( '0', '1', '%', 'comments-link', 'Comments off');?></span>
                    </div>
                    <h3 class="post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                    <p><?php echo wp_trim_words(get_the_content(), 20); ?></p>
                  </div>
                </div>
              </div>
              <?php 
            endwhile; 
            wp_reset_postdata(); 
            else : ?>
            <p><?php echo esc_html__('Sorry, no posts matched your criteria.','wordify'); ?></p>
          <?php endif; ?>
        </div>
      </div>
    </div>
  </div>
</section>
<!-- END section -->
<section class="site-section py-sm">
  <div class="container">
    <div class="row">
      <div class="col-md-6">
        <h2 class="mb-4"><?php _e('Latest Posts','wordify'); ?></h2>
      </div>
    </div>
    <div class="row blog-entries">
      <div class="col-md-12 col-lg-8 main-content">
        <div class="row">
          <?php 
          $gridblog = array(
            'post_type' => 'post',
            'posts_per_page' => 8,
            'paged' => get_query_var('paged') ? get_query_var('paged') : 1
          );
          // the query
          $gridblogquery = new WP_Query( $gridblog ); ?>

          <?php if ( $gridblogquery->have_posts() ) : ?>
            <!-- the loop -->
            <?php while ( $gridblogquery->have_posts() ) : $gridblogquery->the_post(); 

            /*
             * Include the Post-Type-specific template for the content.
             * If you want to override this in a child theme, then include a file
             * called content-___.php (where ___ is the Post Type name) and that will be used instead.
             */
            get_template_part( 'template-parts/post/content', get_post_type() );

            endwhile; ?>
            <!-- end of the loop -->
            <?php wp_reset_postdata(); 

            else : 

            get_template_part( 'template-parts/post/content', 'none' );

          endif; 
          ?>
        </div>
        <div class="row mt-5">
          <div class="col-md-12 text-center">
            <nav aria-label="Page navigation" class="text-center">
              <ul class="pagination">
                <?php $big = 999999999; // need an unlikely integer
                  echo paginate_links( array(
                  'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
                  'format' => '?paged=%#%',
                  'prev_text'          => __( '<li class="page-item">&lt;</li>', 'wordify' ),
                  'next_text'          => __( '<li class="page-item">&gt;</li>', 'wordify' ),
                  'current' => max( 1, get_query_var('paged') ),
                  'total' => $gridblogquery->max_num_pages
                  ) );
                  wp_reset_postdata();
                ?>
              </ul>
            </nav>
          </div>
        </div>
      </div>
      <?php get_sidebar(); ?>
    </div>
  </div>
</section>
<?php get_footer(); ?>
